<!--

This source file is part of the Stanford Spezi Template Application open-source project

SPDX-FileCopyrightText: 2024 Stanford University

SPDX-License-Identifier: MIT

-->

Spezi Data Pipeline Contributors
=================================

* [Vicky Bikia](https://github.com/vicbi)
* [Paul Schmiedmayer](https://github.com/PSchmiedmayer)
* [Adrit Rao](https://github.com/AdritRao)
* [Oliver Aalami](https://github.com/aalami5)